function Q = plotringdown(t0,dur,frange,channel,fignum,name,Nchunk)

    chandata = cacheFunction(@grabdata,{channel},t0,dur);
    dewhite = zpk(-2*pi*[100 100 100 100 100],-2*pi*[1 1 1 1 1],(100)^-5);

    % get high res asd of full set

    resolution = 1/128;
    darmasd = filter(asddata(asd(chandata.data,chandata.rate,resolution)),dewhite);
    
    isub = (darmasd.frequencies<frange(2) & darmasd.frequencies>frange(1));
    fsub = darmasd.frequencies(isub);
    asdsub = darmasd.asd(isub);
    
    [peaks, loc] = findpeaks(asdsub,'SortStr','descend');
    loc = fsub(loc);
    
    if ~isempty(loc)
        fpeak = loc(1);
    else
        fpeak = 111;
    end

    figure(fignum)
    clf
    asddata.plot(darmasd)
    set(gca,'XScale','linear')
    xlim(fpeak+[-2,2])
    %ylim([1e-20,1e-16])
    hold all
    
    if ~isempty(loc)
        plot(loc(1:2), peaks(1:2), 'bo')
    end
    title([name ' spectrum'])

    hold off
    
    % split into chunks, do ASD of chunks
    %Nchunk = 30;
    J = length(chandata.data);
    peakHeight = zeros(Nchunk,1);

    for jj = 1:Nchunk
        chunkdata = chandata.data((jj-1)*J/Nchunk+1:min(jj*J/Nchunk,J));

        chunkasd = filter(asddata(asd(chunkdata,chandata.rate)),dewhite);

        % look at peak height versus time

        frequencies = chunkasd.frequencies;
        [~,ipeak] = min(abs(fpeak-frequencies));

        peakHeight(jj) = chunkasd.asd(ipeak);
    end

    tchunk = ((1:Nchunk)*dur/Nchunk).';

    opts= fitoptions('Method','LinearLeastSquares','Normalize','off');

    linexp = fittype({'x','1'});
    [fitobject,~,~] = fit(tchunk,log(peakHeight),linexp,opts);
    figure(fignum+100)
    clf
    plot(tchunk,peakHeight)
    hold all
    plot(tchunk,exp(feval(linexp,fitobject.a,fitobject.b,tchunk)));
    title([name ' ringdown'])

    % print output
    tau = -1/fitobject.a;
    conf = confint(fitobject);
    tauconf = -1./conf(:,1).';

    Qfit = pi*fpeak*tau;
    Qconf = pi*fpeak*tauconf;
    %phi = 1/Qfit;
    %phiconf = 1./Qconf;

    disp(['*Results for ' name '*'])
    disp(['resonance frequencies: ' num2str(loc(1)) 'Hz, ' num2str(loc(2)) 'Hz.'])
    disp(['Q = **' num2str(Qfit) '** (' num2str(Qconf(1)),', ' num2str(Qconf(2)) ')'])
    %disp(['phi = ' num2str(phi) ' (' num2str(phiconf(1)),', ' num2str(phiconf(2)) ')'])


    Q = Qfit;
end